=====================
manila-tempest-plugin
=====================

Tempest plugin manila-tempest-plugin

Tempest plugin to test Manila's features

* Free software: Apache license
* Documentation: https://docs.openstack.org/manila/latest/
* Release notes: https://docs.openstack.org/releasenotes/manila/
* Source: https://opendev.org/openstack/manila-tempest-plugin
* Bugs: https://bugs.launchpad.net/manila-tempest-plugin

Features
--------

* TODO
